pub struct NativeSharedDictionary { /* private fields */ }Expand description
Pre-parsed shared dictionary that can be reused across multiple tokenizers. The ~150 MB DoubleArrayTrie is shared via Arc, so creating additional tokenizers from this handle is nearly free.
Implementations